Welcome to sfrout’s documentation! — sfrout 0.0.7 documentation

# Welcome to sfrout’s documentation!

main.run(*, domain: str, reports_path: str, reports_list: list[dict[str, str]] = [], summary_filepath: str = '', log_path: str = '', report: str = '', path: str = '', threads: int = 0, stdout_loglevel: str = 'WARNING', file_loglevel: str = 'WARNING', verbose: bool = False) → None

  Main function of the program.

  Parameters:

    - domain (str) – SalesForce domain of your organization -> “https://corp.my.salesforce.com/”

    - reports_path (str) – Path to reports.csv file, template -> https://github.com/LukaszHoszowski/sfrout/blob/main/example/reports-default.csv

    - reports_list (list[dict[str, str]]) – List of the reports as dictionaries -> `[{'name': 'RaportName', 'id': '00O1V00000999GHES', 'path': WindowsPath('C:/downloads')}]`

    - summary_filepath (str) – File path to summary report -> `C:/downloads/summary.csv`

    - log_path (str) – Path to log file -> `C:/downloads/logs/`

    - report (str) – Single report mode -> `RaportName,00O1V00000999GHES,C:/downloads`

    - path (str) – Save location path override -> `C:/new_downloads`

    - threads (int) – Number of threads to use. (Default: `half of available threads of the machine`)

    - stdout_loglevel (str) – Log level for stdout logging -> `['critical'|'error'|'warn'|'warning'|'info'|'debug']` (Default: `WARNING`)

    - file_loglevel (str) – Log level for file logging -> `['critical'|'error'|'warn'|'warning'|'info'|'debug']` (Default: `WARNING`)

    - verbose (bool) – Toggles between Progress Bar and stdout logging (Default: `False`)

# Indices and tables

- Index

- Module Index

- Search Page